@@ -125,6 +125,9 @@ class FindWidget(BaseWidget):
     def setFocus(self):
 
         super(FindWidget, self).setFocus()
+        selection = self.extension_manager.provide('ide_current_selection')
+        if selection and u'\n' not in selection:
+            self.ui.lineedit_needle.setText(selection)
         self.ui.lineedit_needle.setFocus()
 
     def _open_result(self, item, column):
@@ -163,14 +166,23 @@ class FindWidget(BaseWidget):
             needle,
             self._finder.pid
         ))
+        self.extension_manager.fire(
+            'register_subprocess',
+            pid=self._finder.pid,
+            description='find_text_in_files:{}'.format(needle)
+        )
         QTimer.singleShot(1000, self._check_finder)
         
     def _check_finder(self):
         
         if self._queue.empty():
-            oslogger.debug(
-                u'no results yet for finder (PID={})'.format(self._finder.pid)
-            )
+            try:
+                oslogger.debug(u'no results yet for finder (PID={})'.format(
+                        self._finder.pid
+                ))
+            except ValueError:
+                # Is raised when getting the pid of a closed process
+                return
             QTimer.singleShot(1000, self._check_finder)
             return
         path, line_number, matching_line = self._queue.get()
